##  Tags
You have the flexibility to remove existing tags or add new tags to a fact sheet depending on the fact sheet type. To do this, simply click on the Tags area in the Editing pane on the right and directly add or remove tags.
